## 港股实时日线

接口：rt_hk_k

描述：获取港股实时日k线行情，支持按股票代码及股票代码通配符一次性提取全部股票实时日k线行情

限量：单次最大可提取5000条数据

积分：本接口是单独开权限的数据，单独申请权限请参考权限列表

输入参数

| 名称 | 类型 | 必选 | 描述 |
| --- | --- | --- | --- |
| ts_code | str | Y | 支持通配符方式，e.g. 00001.HK、02*.HK |

输出参数

| 名称 | 类型 | 默认显示 | 描述 |
| --- | --- | --- | --- |
| ts_code | str | Y | 股票代码 |
| pre_close | float | Y | 昨收价 |
| close | float | Y | 收盘价 |
| high | float | Y | 最高价 |
| open | float | Y | 开盘价 |
| low | float | Y | 最低价 |
| vol | float | Y | 成交量（股） |
| amount | float | Y | 成交额(元) |

接口示例

```python
#获取特定股票实时日线
df = pro.rt_hk_k(ts_code='00001.HK')

#获取今日开盘以来部分港股实时日线
df = pro.rt_hk_k(ts_code='01*.HK')
```

数据示例

```python
ts_code  pre_close  close   high   open    low            vol       amount
0    01508.HK      1.040  1.030  1.050  1.040  1.030  14971000.0  15564320.00
```